==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","Gai guztiak");
define("_NOCOMMENTS","Komentariorik gabe");

define("_UCOMMENT","Komentarioa");
define("_REVIEWS","Berrikuspenak");
define("_SEARCHUSERS","Kideetan bilatu");
define("_SEARCHSECTIONS","Atal Berezietan bilatu");
define("_SEARCHREVIEWS","Berrikuspenetan bilatu");
define("_SEARCHIN","Non Bilatu:");
define("_ARTICLES","Artikuloak");
define("_ALLAUTHORS","Autore guztiak");
define("_ALL","Guztiak");
define("_WEEK","Astea");
define("_WEEKS","Asteak");
define("_MONTH","Hilabetea");
define("_MONTHS","Hilabeteak");
define("_SEARCHON","Non Bilatu:");
define("_SSTORIES","Notiziak");
define("_SSECTIONS","Atal Bereziak");
define("_SUSERS","Sistema-kideak");
define("_NOMATCHES","Bilaketan ez da aurkitu erregistrorik");
define("_PREVMATCHES","Aurreko erregistroak");
define("_NEXTMATCHES","Ondorengo erregistroak");
define("_INSECTION","Atal berezi honetan:");
define("_NONAME","Ez duzu izenik sartu");
define("_SCOMMENTS","Komentarioak");
define("_SEARCHRESULTS","Bilaketaren emaitzak");
define("_CONTRIBUTEDBY","Honek idatzita:");
define("_UCOMMENTS","Komentarioak");
define("_MATCHTITLE","Tituloa kontutan izanik bilatu");
define("_MATCHTEXT","Edukia kontutan izanik bilatu");
define("_MATCHBOTH","Biak kontutan izanik bilatu");
define("_SREPLY","bat egiten du");
define("_SREPLIES","bat egiten dute");
define("_ATTACHART","Berriari eranztu");
define("_PAGES","Orrialde");
define("_REVIEWSCORE","Berrikuspen honi balorazioa");
define("_PAGE","orrialde ");



?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","Gai guztiak");
define("_NOCOMMENTS","Komentariorik gabe");

define("_UCOMMENT","Komentarioa");
define("_REVIEWS","Berrikuspenak");
define("_SEARCHUSERS","Kideetan bilatu");
define("_SEARCHSECTIONS","Atal Berezietan bilatu");
define("_SEARCHREVIEWS","Berrikuspenetan bilatu");
define("_SEARCHIN","Non Bilatu:");
define("_ARTICLES","Artikuloak");
define("_ALLAUTHORS","Autore guztiak");
define("_ALL","Guztiak");
define("_WEEK","Astea");
define("_WEEKS","Asteak");
define("_MONTH","Hilabetea");
define("_MONTHS","Hilabeteak");
define("_SEARCHON","Non Bilatu:");
define("_SSTORIES","Notiziak");
define("_SSECTIONS","Atal Bereziak");
define("_SUSERS","Sistema-kideak");
define("_NOMATCHES","Bilaketan ez da aurkitu erregistrorik");
define("_PREVMATCHES","Aurreko erregistroak");
define("_NEXTMATCHES","Ondorengo erregistroak");
define("_INSECTION","Atal berezi honetan:");
define("_NONAME","Ez duzu izenik sartu");
define("_SCOMMENTS","Komentarioak");
define("_SEARCHRESULTS","Bilaketaren emaitzak");
define("_CONTRIBUTEDBY","Honek idatzita:");
define("_UCOMMENTS","Komentarioak");
define("_MATCHTITLE","Tituloa kontutan izanik bilatu");
define("_MATCHTEXT","Edukia kontutan izanik bilatu");
define("_MATCHBOTH","Biak kontutan izanik bilatu");
define("_SREPLY","bat egiten du");
define("_SREPLIES","bat egiten dute");
define("_ATTACHART","Berriari eranztu");
define("_PAGES","Orrialde");
define("_REVIEWSCORE","Berrikuspen honi balorazioa");
define("_PAGE","orrialde ");



?>
